#### Quantify Image

Transform Image into tensor (hyper dimentional matrix)

Image will be in 3 color channels, and normalize at this step

The orignal value is a float ranging from 0.0 to 1.0, eg if a pixel is ( 0.99, 0.1 , 0.99 ), means we have a lots of red and blue but very little green, the color will be like this

Normalize will shift the value to cluster around 0.0, using mean and std(standard deviation) for each color channel.

The value will mostly be in range (-1.0, 1.0) for each color channel after normalization